@@ -1,10 +1,13 @@
 """ log machine-parseable test session result information in a plain
 text file.
 """
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
+import os
 
 import py
-import os
 
 
 def pytest_addoption(parser):
